Authors
=======

Originally written by Anthony Scopatz
Significant contributions by Christopher "CJ" Wright and Simon J. L. Billinge
Billinge Group and other community contibutors.

Contributors
------------

For a full list of contributors, visit
https://github.com/regro/regolith/graphs/contributors
